Produces a vector graphics output from R plot instructions and adds the result in an Excel sheet.
Arguments
- x
an
rxlsxobject produced byofficer::read_xlsx- sheet
sheet label/name
- code
plot instructions
- left, top
left and top origin of the plot on the sheet in inches.
- height, width
Height and width in inches.
- ...
arguments passed on to
dml_xlsx.